@@ -35,39 +35,33 @@ sub parse {
 	my $parser = XML::LibXML->new();
   my $doc    = $parser->parse_string($xml);
   my $root   = $doc->documentElement;
-  my $xc     = XML::LibXML::XPathContext->new( $root );
-  $xc->registerNs("marc","http://www.loc.gov/MARC21/slim");
   
   my @out;
-
   my $id = undef;
 
-  for ($xc->findnodes('/marc:record/*')) {
-  		my $name  = $_->nodeName;
-  		my $value = $_->textContent // '';
-
-  		if ($name eq 'leader') {
-  			push @out , ['LDR' , ' ', ' ' , '_' , $value];
-  		}
-  		elsif ($name eq 'controlfield') {
-  			my $tag = $xc->findvalue('@tag',$_);
-  			push @out , [$tag ,  ' ', ' ' , '_' , $value];
-  			$id = $value if $tag eq '001';
-  		}
-  		elsif ($name eq 'datafield') {
-  			my $tag  = $xc->findvalue('@tag',$_);
-  			my $ind1 = $xc->findvalue('@ind1',$_) // ' ';
-  			my $ind2 = $xc->findvalue('@ind2',$_) // ' ';
-  			my @subfield = ();
-  			for ($xc->findnodes('.//marc:subfield',$_)) {
-  				my $code  = $xc->findvalue('@code',$_);
-  				my $value = $_->textContent;
-  				push @subfield , $code;
-  				push @subfield , $value;
-  			}
-
-  			push @out , [$tag ,  $ind1 , $ind2 , '_' , '' , @subfield];
-  		}
+  for my $field ($root->getChildrenByLocalName('*')) {
+      my $name = $field->localname;
+      my $value = $field->textContent // '';
+      if ($name eq 'leader') {
+           push @out, [ 'LDR', ' ', ' ', '_', $value ];
+      }
+      elsif ($name eq 'controlfield') {
+          my $tag = $field->getAttribute( 'tag' );
+          push @out, [ $tag, ' ', ' ', '_', $value ];
+          $id = $value if $tag eq '001';
+      }
+      elsif ( $name eq 'datafield' ) {
+          my $tag  = $field->getAttribute( 'tag' );
+          my $ind1 = $field->getAttribute( 'ind1' ) // ' ';
+          my $ind2 = $field->getAttribute( 'ind2' ) // ' ';
+          my @subfield = ();
+          for my $subfield ( $field->getChildrenByLocalName('subfield') ) {
+              my $code = $subfield->getAttribute( 'code' );
+              my $value = $subfield->textContent;
+              push @subfield, $code, $value;
+          }
+          push @out, [ $tag, $ind1, $ind2, @subfield ];
+      }
   }
 
   return { _id => $id , record => \@out };
